@@ -61,9 +61,17 @@ def get_url_from_gdrive_confirmation(contents):
     return url
 
 
-def _get_session(use_cookies, return_cookies_file=False):
+def _get_session(proxy, use_cookies, return_cookies_file=False):
     sess = requests.session()
 
+    sess.headers.update(
+        {"User-Agent": "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_12_6)"}
+    )
+
+    if proxy is not None:
+        sess.proxies = {"http": proxy, "https": proxy}
+        print("Using proxy:", proxy, file=sys.stderr)
+
     # Load cookies if exists
     cookies_file = osp.join(home, ".cache/gdown/cookies.json")
     if osp.exists(cookies_file) and use_cookies:
@@ -89,6 +97,7 @@ def download(
     id=None,
     fuzzy=False,
     resume=False,
+    format=None,
 ):
     """Download file from URL.
 
@@ -117,6 +126,11 @@ def download(
     resume: bool
         Resume the download from existing tmp file if possible.
         Default is False.
+    format: str, optional
+        Format of Google Docs, Spreadsheets and Slides. Default is:
+            - Google Docs: 'docx'
+            - Google Spreadsheet: 'xlsx'
+            - Google Slides: 'pptx'
 
     Returns
     -------
@@ -131,13 +145,9 @@ def download(
     url_origin = url
 
     sess, cookies_file = _get_session(
-        use_cookies=use_cookies, return_cookies_file=True
+        proxy=proxy, use_cookies=use_cookies, return_cookies_file=True
     )
 
-    if proxy is not None:
-        sess.proxies = {"http": proxy, "https": proxy}
-        print("Using proxy:", proxy, file=sys.stderr)
-
     gdrive_file_id, is_gdrive_download_link = parse_url(url, warning=not fuzzy)
 
     if fuzzy and gdrive_file_id:
@@ -146,18 +156,57 @@ def download(
         url_origin = url
         is_gdrive_download_link = True
 
-    headers = {
-        "User-Agent": "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_10_1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/39.0.2171.95 Safari/537.36"  # NOQA
-    }
-
     while True:
         try:
-            res = sess.get(url, headers=headers, stream=True, verify=verify)
+            res = sess.get(url, stream=True, verify=verify)
         except requests.exceptions.ProxyError as e:
-            print("An error has occurred using proxy:", proxy, file=sys.stderr)
+            print(
+                "An error has occurred using proxy:",
+                sess.proxies,
+                file=sys.stderr,
+            )
             print(e, file=sys.stderr)
             return
 
+        if url == url_origin and res.status_code == 500:
+            # The file could be Google Docs or Spreadsheets.
+            url = "https://drive.google.com/open?id={id}".format(
+                id=gdrive_file_id
+            )
+            continue
+        m = re.search("<title>(.+)</title>", res.text)
+        if m and m.groups()[0].endswith(" - Google Docs"):
+            url = (
+                "https://docs.google.com/document/d/{id}/export"
+                "?format={format}".format(
+                    id=gdrive_file_id,
+                    format="docx" if format is None else format,
+                )
+            )
+            continue
+        elif m and m.groups()[0].endswith(" - Google Sheets"):
+            url = (
+                "https://docs.google.com/spreadsheets/d/{id}/export"
+                "?format={format}".format(
+                    id=gdrive_file_id,
+                    format="xlsx" if format is None else format,
+                )
+            )
+            continue
+        elif (m and m.groups()[0].endswith(" - Google Slides")) or (
+            "Content-Disposition" in res.headers
+            and res.headers["Content-Disposition"].endswith("pptx")
+            and format not in {None, "pptx"}
+        ):
+            url = (
+                "https://docs.google.com/presentation/d/{id}/export"
+                "?format={format}".format(
+                    id=gdrive_file_id,
+                    format="pptx" if format is None else format,
+                )
+            )
+            continue
+
         if use_cookies:
             if not osp.exists(osp.dirname(cookies_file)):
                 os.makedirs(osp.dirname(cookies_file))
@@ -246,7 +295,7 @@ def download(
         f = output
 
     if tmp_file is not None and f.tell() != 0:
-        headers["Range"] = "bytes={}-".format(f.tell())
+        headers = {"Range": "bytes={}-".format(f.tell())}
         res = sess.get(url, headers=headers, stream=True, verify=verify)
 
     if not quiet:
